package sudokuCSP;

import java.util.HashSet;

/**
 *	Class ColumnConstraint.
 *	<p>
 *	This class represents the constraint on the columns of a Sudoku puzzle, namely that<br>
 *	all columns of the puzzle must contain different permutations of the legal domain<br>
 *	values.<br>
 *	<p>
 *	Written by:	Roger West<br>
 *				University of Illinois at Springfield<br>
 *				Jun 26, 2014<br>
 *
 */
public class ColumnConstraint implements SudokuConstraint
{

	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Methods
	///////////////////////////////////////////////////////////////////////////////////////////////

	/**
	 *	Return whether this ColumnConstraint is satisfied based on the current
	 *	assignment thus far.
	 *
	 *	@param	puzzle		the Sudoku puzzle in its current assignment state
	 *
	 *	@return	true if this ColumnConstraint is satisfied
	 *			false otherwise
	 */
	public boolean isSatisfied(SudokuPuzzle puzzle)
	{
		// use a HashSet for O(1) duplicate detection
		HashSet<String> test = new HashSet<String>();
		
		// tally the currently assigned values for each row
		// fail fast and return false if a duplicate value is found in a row
		for (SudokuVariable[] column : puzzle.getAllColumns())
		{
			test = new HashSet<String>();
			
			for (SudokuVariable variable : column)
			{
				if (!variable.getValue().equals(SudokuPuzzle.EMPTY_CELL_VALUE) && test.contains(variable.getValue()))
				{
					// duplicate value found; constraint violated
					return false;
				}
				
				// keep track of non-duplicate value and continue
				test.add(variable.getValue());
			}
		}
		
		// constraint satisfied
		return true;
	}

}
