package sudokuCSP;

import gui.MainFrame;

/**
 *	Class SudokuCSPAgent.
 *	<p>
 *	This class represents an agent with the ability to solve a SudokuPuzzle<br>
 *	as a constraint satisfaction problem (CSP).<br>
 *	<p>
 *	Written by:	Roger West<br>
 *				University of Illinois at Springfield<br>
 *				Jun 26, 2014<br>
 *
 */
public class SudokuCSPAgent
{
	
	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Attributes
	///////////////////////////////////////////////////////////////////////////////////////////////
	
	/** The SudokuPuzzle to be solved. */
	private SudokuPuzzle puzzle;
	
	/** The backtracking search to be used in solving the puzzle. */
	private BacktrackingSearch search;
	

	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Constructors
	///////////////////////////////////////////////////////////////////////////////////////////////

	/**
	 *	Create a new SudokuCSPAgent.
	 *
	 *	@param	puzzle		the SudokuPuzzle this SudokuCSPAgent will try to solve
	 *	@param	search		the type of search algorithm this SudokuCSPAgent will use
	 */
	public SudokuCSPAgent(SudokuPuzzle puzzle, BacktrackingSearch search)
	{
		this.puzzle = puzzle;
		this.search = search;
	}

	
	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Methods
	///////////////////////////////////////////////////////////////////////////////////////////////
	
	/**
	 *	Solve a SudokuPuzzle. Progress and status messages will be displayed via
	 *	the specified application window.
	 *
	 *	@param	mainFrame	the main application window
	 */
	public void solveProblem(MainFrame mainFrame)
	{
		// Search for solution
		SudokuPuzzle solution = search.search(puzzle, mainFrame);
		
		if (solution == null)
		{
			// solution not found
			mainFrame.appendStatus("        Solution not found!");
		}
		else
		{
			// solution found
			mainFrame.appendStatus("        Solution found!");
		}
	}

}
