package sudokuCSP;


/**
 *	Class SudokuVariable.
 *	<p>
 *	This class represents a variable in a SudokuPuzzle constraint satisfaction problem.<br>
 *	<p>
 *	Written by:	Roger West<br>
 *				University of Illinois at Springfield<br>
 *				Jun 26, 2014<br>
 *
 */
public class SudokuVariable
{
	
	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Attributes
	///////////////////////////////////////////////////////////////////////////////////////////////
	
	/** Row position for this SudokuVariable */
	private int row;
	
	/** Column position for this SudokuVariable */
	private int column;
	
	/** value for this SudokuVariable */
	private String value;
	
		
	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Constructors
	///////////////////////////////////////////////////////////////////////////////////////////////
	
	/**
	 *	Create a new SudokuVariable.
	 *	<p>
	 *	@param	row			row position for this SudokuVariable
	 *	@param	column		column position for this SudokuVariable
	 *	@param	value		initial value for this SudokuVariable
	 */
	public SudokuVariable(int row, int column, String value)
	{
		this.row = row;
		this.column = column;
		this.value = value;
	}
	
	
	///////////////////////////////////////////////////////////////////////////////////////////////
	//	Methods
	///////////////////////////////////////////////////////////////////////////////////////////////

	/**
	 *	Return the value for this SudokuVariable.
	 * 
	 *	@return	the value for this SudokuVariable
	 */
	public String getValue()
	{
		return value;
	}


	/**
	 *	Set the value for this SudokuVariable.
	 *
	 *	@param	value	the new value to set for this SudokuVariable
	 */
	public void setValue(String value)
	{
		this.value = value;
	}


	/**
	 *	Return the row position for this SudokuVariable.
	 * 
	 *	@return	the row position for this SudokuVariable
	 */
	public int getRow()
	{
		return row;
	}
	
	
	/**
	 *	Return the column position for this SudokuVariable.
	 * 
	 *	@return	the column position for this SudokuVariable
	 */
	public int getColumn()
	{
		return column;
	}

	
	/**
	 *	Return a String representation of this SudokuVariable.
	 */
	public String toString()
	{
		return "(" + row + ", " + column + ")";
	}
}
